@@ -409,7 +409,7 @@ girara_escape_string(const char* value)
   GString* str = g_string_new("");
   while (*value != '\0') {
     const char c = *value++;
-    if (strchr("\\ \t\"\'", c) != NULL) {
+    if (strchr("\\ \t\"\'#", c) != NULL) {
       g_string_append_c(str, '\\');
     }
     g_string_append_c(str, c);
